==> sapphire-repository-8.0.1.zip: org/eclipse/sapphire/ui/def/ISapphirePartListenerDef.java <==
/******************************************************************************
 * Copyright (c) 2014 Oracle
 * All rights reserved. This program and the accompanying materials
 * are made available under the terms of the Eclipse Public License v1.0
 * which accompanies this distribution, and is available at
 * http://www.eclipse.org/legal/epl-v10.html
 *
 * Contributors:
 *    Konstantin Komissarchik - initial implementation and ongoing maintenance
 ******************************************************************************/

package org.eclipse.sapphire.ui.def;

import org.eclipse.sapphire.Element;
import org.eclipse.sapphire.ElementType;
import org.eclipse.sapphire.ReferenceValue;
import org.eclipse.sapphire.ValueProperty;
import org.eclipse.sapphire.java.JavaType;
import org.eclipse.sapphire.java.JavaTypeName;
import org.eclipse.sapphire.modeling.annotations.Label;
import org.eclipse.sapphire.modeling.annotations.Reference;
import org.eclipse.sapphire.modeling.annotations.Type;
import org.eclipse.sapphire.modeling.xml.annotations.XmlBinding;

/**
 * @author <a href="mailto:konstantin.komissarchik@oracle.com">Konstantin Komissarchik</a>
 */

@Label( standard = "listener" )

public interface ISapphirePartListenerDef extends Element
{
    ElementType TYPE = new ElementType( ISapphirePartListenerDef.class );
    
    // *** ListenerClass ***
    
    @Type( base = JavaTypeName.class )
    @Reference( target = JavaType.class )
    @Label( standard = "listener class" )
    @XmlBinding( path = "" )
    
    ValueProperty PROP_LISTENER_CLASS = new ValueProperty( TYPE, "ListenerClass" );
    
    ReferenceValue<JavaTypeName,JavaType> getListenerClass();
    void setListenerClass( String value );
    void setListenerClass( JavaTypeName value );

}

==> sapphire-repository-9.0.3.zip: org/eclipse/sapphire/ui/def/ISapphirePartListenerDef.java <==
/******************************************************************************
 * Copyright (c) 2015 Oracle
 * All rights reserved. This program and the accompanying materials
 * are made available under the terms of the Eclipse Public License v1.0
 * which accompanies this distribution, and is available at
 * http://www.eclipse.org/legal/epl-v10.html
 *
 * Contributors:
 *    Konstantin Komissarchik - initial implementation and ongoing maintenance
 ******************************************************************************/

package org.eclipse.sapphire.ui.def;

import org.eclipse.sapphire.Element;
import org.eclipse.sapphire.ElementType;
import org.eclipse.sapphire.ReferenceValue;
import org.eclipse.sapphire.Type;
import org.eclipse.sapphire.ValueProperty;
import org.eclipse.sapphire.java.JavaType;
import org.eclipse.sapphire.java.JavaTypeName;
import org.eclipse.sapphire.modeling.annotations.Label;
import org.eclipse.sapphire.modeling.annotations.Reference;
import org.eclipse.sapphire.modeling.xml.annotations.XmlBinding;

/**
 * @author <a href="mailto:konstantin.komissarchik@oracle.com">Konstantin Komissarchik</a>
 */

@Label( standard = "listener" )

public interface ISapphirePartListenerDef extends Element
{
    ElementType TYPE = new ElementType( ISapphirePartListenerDef.class );
    
    // *** ListenerClass ***
    
    @Type( base = JavaTypeName.class )
    @Reference( target = JavaType.class )
    @Label( standard = "listener class" )
    @XmlBinding( path = "" )
    
    ValueProperty PROP_LISTENER_CLASS = new ValueProperty( TYPE, "ListenerClass" );
    
    ReferenceValue<JavaTypeName,JavaType> getListenerClass();
    void setListenerClass( String value );
    void setListenerClass( JavaTypeName value );
    void setListenerClass( JavaType value );

}
